aboutsummaryrefslogtreecommitdiffstats
path: root/include/identity.php
diff options
context:
space:
mode:
Diffstat (limited to 'include/identity.php')
-rw-r--r--include/identity.php8
1 files changed, 6 insertions, 2 deletions
diff --git a/include/identity.php b/include/identity.php
index ead785543..50c5d13b9 100644
--- a/include/identity.php
+++ b/include/identity.php
@@ -361,14 +361,18 @@ function create_identity($arr) {
// Save our permissions role so we can perhaps call it up and modify it later.
- if($role_permissions)
+ if($role_permissions) {
set_pconfig($newuid,'system','permissions_role',$arr['permissions_role']);
+ if(array_key_exists('online',$role_permissions))
+ set_pconfig('system','hide_presence',1-intval($role_permissions['online']));
+ }
- // Create a group with no members. This allows somebody to use it
+ // Create a group with yourself as a member. This allows somebody to use it
// right away as a default group for new contacts.
require_once('include/group.php');
group_add($newuid, t('Friends'));
+ group_add_member($newuid,t('Friends'),$ret['channel']['channel_hash']);
// if our role_permissions indicate that we're using a default collection ACL, add it.